@@ -47,7 +47,7 @@ class GitIssuePublisher(Publisher):
     A class to publish and manage GitHub issues with branch-specific threading and graph updates.
     """
 
-    def __init__(self, _api_key: str, repo: str, branch: str, sha: str):
+    def __init__(self, _api_key: str, repo_name: str, branch: str, sha: str):
         """
         Initializes the GitIssuePublisher with authentication, repository, and branch details.
 
@@ -61,13 +61,13 @@ class GitIssuePublisher(Publisher):
         try:
             _auth = Auth.Token(_api_key)
             self.__github = Github(auth=_auth)
-            self.repo = self.__github.get_repo(repo)
+            self.repo = self.__github.get_repo(repo_name)
             self.branch = branch
             self.sha = sha
             # Get the repository
 
             # Get the commit details based on the SHA
-            commit = repo.get_commit(self.sha)
+            commit = self.repo.get_commit(self.sha)
 
             # Set the user who made the push (the author of the commit)
             self.user = commit.author.login
