@@ -48,6 +48,7 @@ def review(openai_key, assistant_id, token, repo, branch, message, gh_before, sh
         print("No response extracted from the note.")
         return
 
+
     try:
         response = json.loads(response)
     except json.JSONDecodeError:
@@ -82,7 +83,7 @@ def review(openai_key, assistant_id, token, repo, branch, message, gh_before, sh
           'interfaceSegregation_comment': response['codeSOLID']['interfaceSegregation'].get('comment', ''),  # New field
           'dependencyInversion': int(response['codeSOLID']['dependencyInversion'].get('score', 0)),
           'dependencyInversion_comment': response['codeSOLID']['dependencyInversion'].get('comment', ''),  # New field
-      }, {"user": author, "sha": sha, "repo": repo, "branch": branch, "issue": str(issue_number), "comment": str(comment_id)}))
+      }, {"user": author, "sha": sha, "repo": repo, "reviewBy": "AI", "reviewer": "gpt4o"}))
     except Exception as e:
         print(f"Unexpected error: {e}")
 
